@@ -4,11 +4,10 @@ from textops import find
 
 DEV=False
 
-
 def get_resources_dir(packname="manafa", default_res_dir="resources"):
     if DEV:
         return packname + "/" + default_res_dir
-    return sysconfig.get_path("purelib") + "/" + packname + "/" + default_res_dir
+    return sysconfig.get_path("purelib") + "/git " + packname + "/" + default_res_dir
 
 
 def get_pack_dir(packname="manafa"):
